@@ -394,10 +394,9 @@ class GSPeerConnectionBroadcasterPiSocketv2:
 
             # loop.run_until_complete( pc.setLocalDescription(awaitpc.createOffer()))
             asyncio.run(create_and_set_local_description(pc))
-
+            loop.close()
             # syncify_async_function(create_and_set_local_description(pc))
 
-
             self.sio.emit("watcher", {"target": description,
                                       "id": id,
                                       "sdp": json.dumps(
@@ -412,17 +411,21 @@ class GSPeerConnectionBroadcasterPiSocketv2:
                     if type(description) == str:
                         description = ast.literal_eval(description)
                     desc = type('new_dict', (object,), description)
+                    loop = asyncio.new_event_loop()
+                    asyncio.set_event_loop(loop)
                     answer = RTCSessionDescription(sdp=description["sdp"], type=description["type"])
 
-                    syncify_async_function(self.peerConnections[id].setRemoteDescription(answer))
+                    asyncio.run(self.peerConnections[id].setRemoteDescription(answer))
+                    loop.close()
 
         @self.sio.event
         def disconnectBroadcaster(id, desc):
             if id in self.peerConnections:
                 self._logger.info("Disconnected Peer")
-
-                syncify_async_function(asyncio.run(self.peerConnections[id].close()))
-
+                loop = asyncio.new_event_loop()
+                asyncio.set_event_loop(loop)
+                asyncio.run(asyncio.run(self.peerConnections[id].close()))
+                loop.close()
                 self.peerConnections.pop(id, None)
 
         @self.sio.event
